summaryrefslogtreecommitdiffstats
path: root/fs/sandbox/sandboxfs.c
diff options
context:
space:
mode:
Diffstat (limited to 'fs/sandbox/sandboxfs.c')
-rw-r--r--fs/sandbox/sandboxfs.c4
1 files changed, 2 insertions, 2 deletions
diff --git a/fs/sandbox/sandboxfs.c b/fs/sandbox/sandboxfs.c
index 5acfc03704..2703eed208 100644
--- a/fs/sandbox/sandboxfs.c
+++ b/fs/sandbox/sandboxfs.c
@@ -8,10 +8,10 @@
#include <fs.h>
#include <os.h>
-int sandbox_fs_set_blk_dev(block_dev_desc_t *rbdd, disk_partition_t *info)
+int sandbox_fs_set_blk_dev(struct blk_desc *rbdd, disk_partition_t *info)
{
/*
* Only accept a NULL block_dev_desc_t for the sandbox, which is when
* hostfs interface is used
*/
return rbdd != NULL;
@@ -8,10 +8,10 @@
{
/*
- * Only accept a NULL block_dev_desc_t for the sandbox, which is when
+ * Only accept a NULL struct blk_desc for the sandbox, which is when
* hostfs interface is used
*/
OpenPOWER on IntegriCloud